@@ -21,21 +21,14 @@
 #include "phabricatorjobs.h"
 #include "debug.h"
 
-#include <QTimer>
 #include <QProcess>
+#include <QRegularExpression>
 #include <QStandardPaths>
 #include <QDir>
-// #include <QFile>
-// #include <QJsonDocument>
-// #include <QMimeDatabase>
-// #include <QMimeType>
-// #include <QNetworkReply>
-// #include <QNetworkRequest>
-// #include <QUrlQuery>
-
+// // // // // // // 
 #include <KLocalizedString>
 
-#define COLOURCODES "\u001B[[0-9]*m"
+const char s_colourCodes[] = "\u001B[[0-9]*m";
 
 using namespace Phabricator;
 
@@ -101,7 +94,7 @@ void DifferentialRevision::start()
 
 void DifferentialRevision::setErrorString(const QString& msg)
 {
-    QRegExp unwanted(QString::fromUtf8(COLOURCODES));
+    QRegularExpression unwanted(QString::fromUtf8(s_colourCodes));
     m_errorString = msg;
     m_errorString.replace(unwanted, QString());
 }
@@ -110,7 +103,7 @@ QString DifferentialRevision::scrubbedResult()
 {
     QString result = QString::fromUtf8(m_arcCmd.readAllStandardOutput());
     // the return string can contain terminal text colour codes: remove them.
-    QRegExp unwanted(QString::fromUtf8(COLOURCODES));
+    QRegularExpression unwanted(QString::fromUtf8(s_colourCodes));
     result.replace(unwanted, QString());
     return result;
 }
@@ -119,7 +112,7 @@ QStringList DifferentialRevision::scrubbedResultList()
 {
     QStringList result = QString::fromUtf8(m_arcCmd.readAllStandardOutput()).split(QChar::LineFeed);
     // the return string can contain terminal text colour codes: remove them.
-    QRegExp unwanted(QString::fromUtf8(COLOURCODES));
+    QRegularExpression unwanted(QString::fromUtf8(s_colourCodes));
     result.replaceInStrings(unwanted, QString());
     // remove all (now) empty strings
     result.removeAll(QString());
@@ -240,10 +233,10 @@ void DiffRevList::done(int exitCode, QProcess::ExitStatus exitStatus)
             << m_arcCmd.error() << ";" << errorString();
     } else {
         setPercent(99);
-        QStringList reviews = scrubbedResultList();
+        const QStringList reviews = scrubbedResultList();
         qCDebug(PLUGIN_PHABRICATOR) << "arc list returned:" << reviews;
-        foreach (auto rev, reviews) {
-            QRegExp revIDExpr(QString::fromUtf8(" D[0-9][0-9]*: "));
+        const QRegularExpression revIDExpr(QStringLiteral(" D[0-9][0-9]*: "));
+        for (auto rev : reviews) {
             int idStart = rev.indexOf(revIDExpr);
             if (idStart >= 0) {
                 QString revID = rev.mid(idStart+1).split(QString::fromUtf8(": ")).at(0);
