@@ -26,4 +26,8 @@ void PurposeQuickPlugin::registerTypes(const char* uri)
     qmlRegisterType<Purpose::AlternativesModel>(uri, 1, 0, "PurposeAlternativesModel");
     qmlRegisterUncreatableType<Purpose::Job>(uri, 1, 0, "PurposeJob", QStringLiteral("You're not supposed to instantiate jobs"));
     qmlRegisterUncreatableType<Purpose::Configuration>(uri, 1, 0, "PurposeConfiguration", QStringLiteral("You're not supposed to instantiate configurations"));
+
+    qmlRegisterType(QUrl(QStringLiteral("qrc:/org/kde/purpose/PurposeWizard.qml")), uri, 1, 0, "PurposeWizard");
+    qmlRegisterType(QUrl(QStringLiteral("qrc:/org/kde/purpose/AlternativesView.qml")), uri, 1, 0, "AlternativesView");
+    qmlRegisterType(QUrl(QStringLiteral("qrc:/org/kde/purpose/RunningJob.qml")), uri, 1, 0, "RunningJob");
 }
